set YES_ 257
set NO_ 258
set ON_ 259
set OFF_ 260
set TRUE_ 261
set FALSE_ 262
set WCS_ 263
set WCSA_ 264
set WCSB_ 265
set WCSC_ 266
set WCSD_ 267
set WCSE_ 268
set WCSF_ 269
set WCSG_ 270
set WCSH_ 271
set WCSI_ 272
set WCSJ_ 273
set WCSK_ 274
set WCSL_ 275
set WCSM_ 276
set WCSN_ 277
set WCSO_ 278
set WCSP_ 279
set WCSQ_ 280
set WCSR_ 281
set WCSS_ 282
set WCST_ 283
set WCSU_ 284
set WCSV_ 285
set WCSW_ 286
set WCSX_ 287
set WCSY_ 288
set WCSZ_ 289
set FK4_ 290
set B1950_ 291
set FK5_ 292
set J2000_ 293
set ICRS_ 294
set GALACTIC_ 295
set ECLIPTIC_ 296
set DEGREES_ 297
set SEXAGESIMAL_ 298
set INT_ 299
set STRING_ 300
set ALIGN_ 301
set APPEND_ 302
set CLOSE_ 303
set LOAD_ 304
set OPEN_ 305
set REPLACE_ 306
set RESET_ 307
set SAVE_ 308
set SKY_ 309
set SKYFORMAT_ 310
set SYSTEM_ 311
